// eslint-disable-next-line import/no-extraneous-dependencies
import React, { createContext, useEffect, useMemo, useState } from 'react';
import { Spin } from '@arco-design/web-react';
import { LoaderContext, useLoaderApi } from "../globalLoader";
import { LOCAL_STORAGE_KEY_WORKSPACE_DARK_MODE } from "../constants";
import "../style/global.scss";
import styles from "./workspaceContext.module.scss";
export const WorkspaceContext = /*#__PURE__*/createContext({
  name: '',
  darkMode: false,
  setDarkMode: () => {},
  components: [],
  overviewScrollContainerID: ''
});
export function WorkspaceContextProvider(props) {
  const {
    name,
    children,
    overviewScrollContainerID
  } = props;
  const [loaderApi, isLoading] = useLoaderApi();
  const [darkMode, setDarkMode] = useState(() => {
    return +localStorage.getItem(LOCAL_STORAGE_KEY_WORKSPACE_DARK_MODE) > 0;
  });
  const workspaceContextValue = useMemo(() => {
    return {
      name,
      darkMode,
      setDarkMode: dark => {
        setDarkMode(dark);
        localStorage.setItem(LOCAL_STORAGE_KEY_WORKSPACE_DARK_MODE, dark ? '1' : '0');
      },
      overviewScrollContainerID,
      components: props.components
    };
  }, [name, darkMode, setDarkMode, overviewScrollContainerID, JSON.stringify(props.components)]);
  useEffect(() => {
    darkMode ? document.body.setAttribute('arco-theme', 'dark') : document.body.removeAttribute('arco-theme');
  }, [darkMode]);
  return /*#__PURE__*/React.createElement(WorkspaceContext.Provider, {
    value: workspaceContextValue
  }, /*#__PURE__*/React.createElement(LoaderContext.Provider, {
    value: loaderApi
  }, /*#__PURE__*/React.createElement(Spin, {
    loading: isLoading,
    className: styles.loader
  }, children)));
}